@@ -4,13 +4,14 @@ from .snappi_convergence import Port
 from .snappi_convergence import PortIter
 from .snappi_convergence import Lag
 from .snappi_convergence import LagPort
-from .snappi_convergence import LagProtocol
-from .snappi_convergence import LagLacp
-from .snappi_convergence import LagStatic
+from .snappi_convergence import LagPortLacp
 from .snappi_convergence import DeviceEthernetBase
 from .snappi_convergence import DeviceVlan
 from .snappi_convergence import DeviceVlanIter
 from .snappi_convergence import LagPortIter
+from .snappi_convergence import LagProtocol
+from .snappi_convergence import LagProtocolLacp
+from .snappi_convergence import LagProtocolStatic
 from .snappi_convergence import LagIter
 from .snappi_convergence import Layer1
 from .snappi_convergence import Layer1AutoNegotiation
@@ -30,6 +31,7 @@ from .snappi_convergence import CaptureFilterIter
 from .snappi_convergence import CaptureIter
 from .snappi_convergence import Device
 from .snappi_convergence import DeviceEthernet
+from .snappi_convergence import EthernetConnection
 from .snappi_convergence import DeviceIpv4
 from .snappi_convergence import DeviceIpv4Iter
 from .snappi_convergence import DeviceIpv6
@@ -67,22 +69,37 @@ from .snappi_convergence import IsisV6RouteRangeIter
 from .snappi_convergence import DeviceBgpRouter
 from .snappi_convergence import BgpV4Interface
 from .snappi_convergence import BgpV4Peer
-from .snappi_convergence import BgpAdvanced
-from .snappi_convergence import BgpCapability
-from .snappi_convergence import BgpV4RouteRange
+from .snappi_convergence import BgpV4EthernetSegment
+from .snappi_convergence import BgpEthernetSegmentDfElection
+from .snappi_convergence import BgpV4EvpnEvis
+from .snappi_convergence import BgpV4EviVxlan
+from .snappi_convergence import BgpV4EviVxlanBroadcastDomain
+from .snappi_convergence import BgpCMacIpRange
+from .snappi_convergence import MACRouteAddress
 from .snappi_convergence import BgpRouteAdvanced
 from .snappi_convergence import BgpCommunity
 from .snappi_convergence import BgpCommunityIter
+from .snappi_convergence import BgpExtCommunity
+from .snappi_convergence import BgpExtCommunityIter
 from .snappi_convergence import BgpAsPath
 from .snappi_convergence import BgpAsPathSegment
 from .snappi_convergence import BgpAsPathSegmentIter
+from .snappi_convergence import BgpCMacIpRangeIter
+from .snappi_convergence import BgpV4EviVxlanBroadcastDomainIter
+from .snappi_convergence import BgpRouteDistinguisher
+from .snappi_convergence import BgpRouteTarget
+from .snappi_convergence import BgpRouteTargetIter
+from .snappi_convergence import BgpV4EvpnEvisIter
+from .snappi_convergence import BgpV4EthernetSegmentIter
+from .snappi_convergence import BgpAdvanced
+from .snappi_convergence import BgpCapability
+from .snappi_convergence import BgpLearnedInformationFilter
+from .snappi_convergence import BgpV4RouteRange
 from .snappi_convergence import BgpAddPath
 from .snappi_convergence import BgpV4RouteRangeIter
 from .snappi_convergence import BgpV6RouteRange
 from .snappi_convergence import BgpV6RouteRangeIter
 from .snappi_convergence import BgpSrteV4Policy
-from .snappi_convergence import BgpExtCommunity
-from .snappi_convergence import BgpExtCommunityIter
 from .snappi_convergence import BgpSrteV4TunnelTlv
 from .snappi_convergence import BgpSrteRemoteEndpointSubTlv
 from .snappi_convergence import BgpSrteColorSubTlv
@@ -119,8 +136,32 @@ from .snappi_convergence import BgpV4InterfaceIter
 from .snappi_convergence import BgpV6Interface
 from .snappi_convergence import BgpV6Peer
 from .snappi_convergence import BgpV6SegmentRouting
+from .snappi_convergence import BgpV6EthernetSegment
+from .snappi_convergence import BgpV6EvpnEvis
+from .snappi_convergence import BgpV6EviVxlan
+from .snappi_convergence import BgpV6EviVxlanBroadcastDomain
+from .snappi_convergence import BgpV6EviVxlanBroadcastDomainIter
+from .snappi_convergence import BgpV6EvpnEvisIter
+from .snappi_convergence import BgpV6EthernetSegmentIter
 from .snappi_convergence import BgpV6PeerIter
 from .snappi_convergence import BgpV6InterfaceIter
+from .snappi_convergence import DeviceVxlan
+from .snappi_convergence import VxlanV4Tunnel
+from .snappi_convergence import VxlanV4TunnelDestinationIPMode
+from .snappi_convergence import VxlanV4TunnelDestinationIPModeUnicast
+from .snappi_convergence import VxlanV4TunnelDestinationIPModeUnicastVtep
+from .snappi_convergence import VxlanTunnelDestinationIPModeUnicastArpSuppressionCache
+from .snappi_convergence import VxlanTunnelDestinationIPModeUnicastArpSuppressionCacheIter
+from .snappi_convergence import VxlanV4TunnelDestinationIPModeUnicastVtepIter
+from .snappi_convergence import VxlanV4TunnelDestinationIPModeMulticast
+from .snappi_convergence import VxlanV4TunnelIter
+from .snappi_convergence import VxlanV6Tunnel
+from .snappi_convergence import VxlanV6TunnelDestinationIPMode
+from .snappi_convergence import VxlanV6TunnelDestinationIPModeUnicast
+from .snappi_convergence import VxlanV6TunnelDestinationIPModeUnicastVtep
+from .snappi_convergence import VxlanV6TunnelDestinationIPModeUnicastVtepIter
+from .snappi_convergence import VxlanV6TunnelDestinationIPModeMulticast
+from .snappi_convergence import VxlanV6TunnelIter
 from .snappi_convergence import DeviceIter
 from .snappi_convergence import Flow
 from .snappi_convergence import FlowTxRx
@@ -418,6 +459,15 @@ from .snappi_convergence import PatternFlowIgmpv1UnusedCounter
 from .snappi_convergence import PatternFlowIgmpv1Checksum
 from .snappi_convergence import PatternFlowIgmpv1GroupAddress
 from .snappi_convergence import PatternFlowIgmpv1GroupAddressCounter
+from .snappi_convergence import FlowMpls
+from .snappi_convergence import PatternFlowMplsLabel
+from .snappi_convergence import PatternFlowMplsLabelCounter
+from .snappi_convergence import PatternFlowMplsTrafficClass
+from .snappi_convergence import PatternFlowMplsTrafficClassCounter
+from .snappi_convergence import PatternFlowMplsBottomOfStack
+from .snappi_convergence import PatternFlowMplsBottomOfStackCounter
+from .snappi_convergence import PatternFlowMplsTimeToLive
+from .snappi_convergence import PatternFlowMplsTimeToLiveCounter
 from .snappi_convergence import FlowHeaderIter
 from .snappi_convergence import FlowSize
 from .snappi_convergence import FlowSizeIncrement
@@ -475,5 +525,5 @@ from .snappi_convergence import Bgpv4MetricIter
 from .snappi_convergence import Bgpv6Metric
 from .snappi_convergence import Bgpv6MetricIter
 from .snappi_convergence import Api
-from .snappi_convergence import HttpApi
+from .snappi_convergence import Transport
 from .snappi_convergence import api
